package models

import (
	"fmt"
	"github.com/beego/beego/v2/client/orm"
	"time"
)

// ChartPermission 报告权限表
type ChartPermission struct {
	ChartPermissionId     int       `orm:"column(chart_permission_id);pk" gorm:"column:chart_permission_id;primaryKey"` //`orm:"column(chart_permission_id);pk" gorm:"primaryKey"  description:"问题ID" json:"chart_permission_id"`
	ChartPermissionName   string    `gorm:"column:chart_permission_name"`                                               //`description:"名称" json:"chart_permission_name"`
	PermissionName        string    `gorm:"column:permission_name"`                                                     //`description:"权限名" json:"permission_name"`
	Sort                  int       `gorm:"column:sort"`                                                                //`description:"排序" json:"sort"`
	Enabled               int       `gorm:"column:enabled"`                                                             //`description:"是否可用" json:"enabled"`
	CreatedTime           time.Time `gorm:"column:created_time"`                                                        //`description:"创建时间" json:"created_time"`
	LastUpdatedTime       time.Time `gorm:"column:last_updated_time"`                                                   //`description:"更新时间" json:"last_updated_time"`
	TeleconferenceSort    int       `gorm:"column:teleconference_sort"`                                                 //`description:"电话会类型排序" json:"teleconference_sort"`
	Remark                string    `gorm:"column:remark"`                                                              //`description:"备注" json:"remark"`
	ClassifyName          string    `gorm:"column:classify_name"`                                                       //`description:"分类名称" json:"classify_name"`
	ProductName           string    `gorm:"column:product_name"`                                                        //`description:"产品名称" json:"product_name"`
	ProductId             int       `gorm:"column:product_id"`                                                          //`description:"产品ID" json:"product_id"`
	ImageURL              string    `gorm:"column:image_url"`                                                           //`orm:"column(image_url);" description:"图片地址" json:"image_url"`
	ShowType              int       `gorm:"column:show_type"`                                                           //`description:"1:查研观向小程序展示" json:"show_type"`
	IsOther               int       `gorm:"column:is_other"`                                                            //`description:"是否是其他，用于查研观向小程序后台展示" json:"is_other"`
	IsReport              int       `gorm:"column:is_report"`                                                           //`description:"是否是报告，用于查研观向小程序前台报告展示" json:"is_report"`
	CygxAuth              int       `gorm:"column:cygx_auth"`                                                           //`description:"是否是权限，用于查研观向小程序前台权限校验" json:"cygx_auth"`
	PermissionType        int       `gorm:"column:permission_type"`                                                     //`description:"1主观，2客观" json:"permission_type"`
	YbImgUrl              string    `gorm:"column:yb_img_url"`                                                          //`description:"研报小程序报告列表icon" json:"yb_img_url"`
	ProductPermissionName string    `gorm:"column:product_permission_name"`                                             //`description:"种类权限名称" json:"product_permission_name"`
	PriceDrivenState      int       `gorm:"column:price_driven_state"`                                                  //`description:"品种价格驱动开启状态 0-关闭 1-开启" json:"price_driven_state"`
	ImageUrlM             string    `gorm:"column:image_url_m"`                                                         //`description:"图片地址(查研观向移动端)" json:"image_url_m"`
	ParentId              int       `gorm:"column:parent_id"`                                                           //`description:"父级权限id" json:"parent_id"`
	IsPublic              int       `gorm:"column:is_public"`                                                           //`description:"是否是公有权限1:公有权限，0私有权限" json:"is_public"`
}

// GetItemsByCondition 查询列表
func (m *ChartPermission) GetItemsByCondition(condition string, pars []interface{}) (items []*ChartPermission, err error) {
	o := orm.NewOrmUsingDB("weekly")
	sql := fmt.Sprintf(`SELECT * FROM chart_permission WHERE 1=1 %s ORDER BY sort ASC, chart_permission_id ASC`, condition)
	_, err = o.Raw(sql, pars).QueryRows(&items)
	return
}

type ChartPermissionItem struct {
	PermissionId   int                    `description:"品种权限ID"`
	PermissionName string                 `description:"品种权限名称"`
	ParentId       int                    `description:"父级ID"`
	Enabled        int                    `description:"是否可用：1可用，0不可用" `
	Sort           int                    `description:"排序"`
	CreateTime     string                 `description:"创建时间"`
	IsPublic       int                    `description:"是否是公有权限1:公有权限，0私有权限"`
	Child          []*ChartPermissionItem `description:"子分类"`
}

type BusinessReportPermissionResp struct {
	CheckList []int                  `description:"选中的权限"`
	List      []*ChartPermissionItem `description:"权限列表"`
}
