package eta_business

import (
	"time"

	"github.com/beego/beego/v2/client/orm"
)

type BusinessAiPredictModelPermission struct {
	AiPredictModelPermissionId int       `orm:"column(ai_predict_model_permission_permission_id);pk"`
	AiPredictModelClassifyId   int       `description:"AI预测模型分类ID"`
	BusinessCode              string    `description:"商户号"`
	EtaBusinessId             int       `description:"商家ID"`
	AdminId                   int       `description:"系统用户Id"`
	ModifyTime                time.Time `description:"变更时间"`
	CreateTime                time.Time `description:"关系建立时间"`
}

func AddBusinessAiPredictModelPermission(list []*BusinessAiPredictModelPermission, businessCode string) (err error) {
	// 事务，先执行删除，再新增
	o := orm.NewOrm()

	to, err := o.Begin()
	if err != nil {
		return
	}
	defer func() {
		if err != nil {
			_ = to.Rollback()
		} else {
			_ = to.Commit()
		}
	}()
	sql := `DELETE FROM business_ai_predict_model_permission WHERE business_code = ?`
	_, err = to.Raw(sql, businessCode).Exec()
	if err != nil {
		return
	}
	if len(list) > 0 {
		_, err = o.InsertMulti(len(list), list)
		return
	}
	return
}

type AddBusinessAiPredictModelPermissionReq struct {
	EtaBusinessId             int    `description:"商家ID"`
	AiPredictModelClassifyIds string `description:"AI预测模型分类ID,多个用英文逗号隔开"`
}

// 获取商家AI预测模型权限
func GetBusinessAiPredictModelPermission(businessId int) (list []*BusinessAiPredictModelPermission, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM business_ai_predict_model_permission WHERE eta_business_id = ?`
	_, err = o.Raw(sql, businessId).QueryRows(&list)
	return
} 