package eta_business

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type BusinessReportPermission struct {
	BusinessReportPermissionId int       `orm:"column(business_report_permission_id);pk"`
	ChartPermissionId          int       `description:"权限ID"`
	EtaBusinessId              int       `description:"商家ID"`
	BusinessCode               string    `description:"商户号"`
	AdminId                    int       `description:"操作人ID"`
	CreateTime                 time.Time `description:"创建时间"`
	ModifyTime                 time.Time `description:"更新时间"`
}

func AddBusinessReportPermission(list []*BusinessReportPermission, businessCode string) (err error) {
	// 事务，先执行删除，再新增
	o := orm.NewOrm()

	to, err := o.Begin()
	if err != nil {
		return
	}
	defer func() {
		if err != nil {
			_ = to.Rollback()
		} else {
			_ = to.Commit()
		}
	}()
	sql := `DELETE FROM business_report_permission WHERE business_code = ?`
	_, err = to.Raw(sql, businessCode).Exec()
	if err != nil {
		return
	}
	if len(list) > 0 {
		_, err = o.InsertMulti(len(list), list)
		return
	}
	return
}

type AddBusinessReportPermissionReq struct {
	EtaBusinessId      int   `description:"商家ID"`
	ChartPermissionIds []int `description:"报告分类IDs"`
}

// GetBusinessReportPermission 获取商家报告权限
func GetBusinessReportPermission(businessId int) (list []*BusinessReportPermission, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM business_report_permission WHERE eta_business_id = ?`
	_, err = o.Raw(sql, businessId).QueryRows(&list)
	return
}
